#!/bin/sh
#
# AddPoint Network Setup Script
#
# Author:      NEC Soft, Ltd.<linux-g@s1.itd.nes.nec.co.jp>
# description: AddPoint is Appliance Server of NEC Soft.
# $Id: addpoint.sh,v 1.13 2006/03/17 01:03:30 oshima Exp $
#                          Copyright (C) NEC Soft, Ltd. 2003-2004

###########################################################################

###########################################################################
#History : Version  Date        Name          Comment
#          1.5.0.1  2007/07/03  harima        single&ma&fa -> marge
#          1.5.0.2  2007/07/05  harima        DIR -> divide
#          1.5.0.3  2007/07/09  K.Hayakawa    FD Device /dev/fd0 /dev/sdb
#          1.5.0.4  2007/10/22  harima        conf.inf isn't exist in FD
#          1.5.0.x  2007/xx/xx  XXXXXXXXXXXX  XXXXXXXXXXXXXXXXXXXXXXXXXXXX
#                                             XXXXXXXXXXXXXXXXXXXXXXXXXXXX
###########################################################################

# Configs #
###########

# location of config file for "mtype"
AP_CONFSRC=conf.inf
#FD_MNTPT=/mnt/floppy
#kanemoto
FD_MNTPT=/media/floppy
# Ver. 1.5.0.3  2007/07/09  K.Hayakawa chg start
FD_MNDEV=/dev/fd0
FD_MNUSB=/dev/sdb
# Ver. 1.5.0.3  2007/07/09  K.Hayakawa chg end

# locations of files to reflect configs
AP_CONF=/tmp/conf.inf-`date '+%Y%m%d-%H%M%S'`
AP_HTPASSWD=/etc/addpoint/.htpasswd
AP_CMCFG=/var/www/cgi-bin/addpoint/withauth/common_config.pl
AP_PRODESC=/etc/addpoint/product

HTTP_CONF=/etc/httpd/conf/httpd.conf

#solo
if [ -d /opt/Guardian/WALL ]; then
	WALLDIR=/opt/Guardian/WALL
elif [ -d /opt/MailGuardian/Wall ]; then
	WALLDIR=/opt/MailGuardian/Wall
else
	WALLDIR=""
fi

#addpointv5sa
if [ -d /opt/Guardian/Admin ]; then
	SRCHMADIR=/opt/Guardian/Admin
elif [ -d /opt/MailGuardian/Admin ]; then
	SRCHMADIR=/opt/MailGuardian/Admin
else
	SRCHMADIR=""
fi


SM_MCORIG=/etc/mail/sendmail.mc
if [ -f /etc/sendmail.cf ]; then
	SM_CF=/etc/sendmail.cf
else
	SM_CF=/etc/mail/sendmail.cf
fi
SM_MAILERTABLE=/etc/mail/mailertable

CONF_TAR=/var/addpoint/conf.tar

export AP_CONFSRC
export AP_CONF AP_HTPASSWD AP_CMCFG AP_PRODESC
export HTTP_CONF
export WALLDIR
export SRCHMADIR
export SM_MCORIG SM_CF SM_MAILERTABLE



##########################################################################
# subroutine #
##############

ap_logger()
{
	logger -t addpoint "$1"
	return $?
}


##########################################################################
# Main routine #
################

ap_logger "Changing network configuration from conf file on floppy disk..."


#======================#
# Read the config file #
#======================#

# for mtools-3.9.9 or newer
#AP_CONFERR=`mtype -t -i `awk '$2~/\/floppy$/{print $1}' /etc/fstab` ::${AP_CONF} 2>&1 1>${AP_CONF}`

#kanemoto
if [ ! -d ${FD_MNTPT} ]; then
	mkdir -p ${FD_MNTPT}
fi

# Ver. 1.5.0.3  2007/07/09  K.Hayakawa add start
#ERR_MESSAGE=`mount -o ro ${FD_MNDEV} ${FD_MNTPT} 2>&1`
#if [ "" != "${ERR_MESSAGE}" ]; then
#    ap_logger "${ERR_MESSAGE}"
#    ap_logger "Next device mounting."
#    ERR_MESSAGE=`mount -o ro ${FD_MNUSB} ${FD_MNTPT} 2>&1`
#    if [ "" != "${ERR_MESSAGE}" ]; then
#        ap_logger "${ERR_MESSAGE}"
#        ap_logger "Configulation wasn't change."
#	exit 1
#    fi
#fi

#cp ${FD_MNTPT}/${AP_CONFSRC} ${AP_CONF}
#umount ${FD_MNTPT}
# Ver. 1.5.0.3  2007/07/09  K.Hayakawa add end

# Ver. 1.5.0.3  2007/07/09  K.Hayakawa add start
# Ver. 1.5.0.4  2007/10/22  harima change start
ERR_MESSAGE=`mount -o ro ${FD_MNDEV} ${FD_MNTPT} 2>&1`
if [ "" != "${ERR_MESSAGE}" ]; then
    ap_logger "${ERR_MESSAGE}"
    ap_logger "Next device mounting."
    ERR_MESSAGE=`mount -o ro ${FD_MNUSB} ${FD_MNTPT} 2>&1`
    if [ "" != "${ERR_MESSAGE}" ]; then
        ap_logger "${ERR_MESSAGE}"
        ap_logger "Configulation wasn't change."
        exit 1
    fi

    if [ ! -r ${FD_MNTPT}/${AP_CONFSRC} ]; then
        ap_logger "Can't Read Conf File:${FD_MNTPT}/${AP_CONFSRC}"
        ap_logger "Configulation wasn't change."
        exit 1
    fi
else
    if [ ! -r ${FD_MNTPT}/${AP_CONFSRC} ]; then
        ap_logger "Can't Read Conf File:${FD_MNDEV}/${AP_CONFSRC}"
        ap_logger "Configulation wasn't change."
        exit 1
    fi
fi

cp ${FD_MNTPT}/${AP_CONFSRC} ${AP_CONF}
umount ${FD_MNTPT}
# Ver. 1.5.0.3  2007/07/09  K.Hayakawa add end
# Ver. 1.5.0.4  2007/10/22  harima change end



# convert CR+LF to LF
perl -i -p -e 's/\r\n/\n/' ${AP_CONF}

# If the line start with '#', delete as comment
perl -i -p -e 's/^#.*//' ${AP_CONF}


#=========================#
# Reflecting the settings #
#=========================#

# Check version of the config file
AP_CFGVER=`grep ^version ${AP_CONF} | cut -d '=' -f 2 \
                                    | sed 's/[ 	]*\"\(.*\)\"[ 	]*/\1/'`
#AP_CFGVER=`awk -F = '/^version/{print $2}' ${AP_CONF} | sed 's/[	 ]*\"\(.*\)\"[	 ]*/\1/'`
AP_PNAME=`awk -F = '/^pname/{print $2}' ${AP_CONF} | sed 's/[	 ]*\"\(.*\)\"[	 ]*/\1/'`

# reflect the config
case ${AP_CFGVER} in
#harima
	5.* )
    case ${AP_CFGVER} in
            *-sa)
		addpoint.v5sa
		;;
            *-sf)
		addpoint.v5sf
		;;
            * )
		addpoint.v5
		;;
    esac
	;;
	3 | 3.* | 4.* )
		addpoint.v3
		;;
	* )
		echo ${AP_PNAME} | grep 'SpamWallServer' >/dev/null 2>&1
		if [ $? -eq 0 -a "${AP_CFGVER}" = '1.0' ]; then
			addpoint.v3
		else
			addpoint.v2
		fi
		;;
esac


# Delete temporary file.
tar rf ${CONF_TAR} -C `dirname ${AP_CONF}` `basename ${AP_CONF}`
rm ${AP_CONF}

ap_logger "Configuration changed."

exit 0
